﻿package com.webdevils {
	// Import statements
	import flash.display.*;
	import flash.net.*;
	import flash.text.*;
	import flash.events.*;

	public class ImageLoader extends MovieClip {
		// Class variables
		private var loader:Loader;

		private var image_width:Number;
		private var image_height:Number;

		private var mask_mc:Sprite;
		private var border_mc:Sprite;
		
		private var border_weight:Number;
		private var border_color:uint;
		
		private var percent_txt:TextField;
		
		private var font_id:*; // Added this variable to hold an embedded font
		private var font_size:uint; // Added this to hold the font size for an embedded font
		
		
		/* Constructor function */
		public function ImageLoader( _url:String, 
									_w:Number, 
									_h:Number, 
									_border_weight:Number = 1, 
									_border_color:uint = 0x000000,
									_font:* = "",
									_font_size:uint = 12 ) { // Add this parameter to add an embeded font, 
													// Pass the Class name of the Font that is Exported from the your library
			
			image_width = _w;
			image_height = _h;
			border_weight = _border_weight;
			border_color = _border_color;
			
			font_id = _font; 		// Store the font_id 
			font_size = _font_size; // Store the font size

			make_loader();
			make_mask();
			make_border();
			make_percent_text();
			redraw_image();

			if ( _url != "" ) {
				load_image( _url );
			}
			
		}
		
		
		/* Private functions */
		private function make_mask():void {
			mask_mc = new Sprite();
			addChild( mask_mc );
			loader.mask = mask_mc;
		}
		private function redraw_image():void {
			mask_mc.graphics.clear();
			mask_mc.graphics.beginFill( 0xFF00FF );
			mask_mc.graphics.drawRect( 0, 0, image_width, image_height );
			mask_mc.graphics.endFill();
			
			border_mc.graphics.clear();
			border_mc.graphics.lineStyle( border_weight, border_color );
			border_mc.graphics.drawRect( 0, 0, image_width, image_height );
		}
		private function make_loader():void {
			loader = new Loader();
			addChild( loader );
			loader.contentLoaderInfo.addEventListener( ProgressEvent.PROGRESS, on_progress );
			loader.contentLoaderInfo.addEventListener( Event.COMPLETE, on_complete );
			loader.addEventListener( IOErrorEvent.IO_ERROR, on_error );
		}
		
		private function on_error( e:IOErrorEvent ):void {
			trace( "*** IO Error ***" );
		}
		
		private function make_border():void {
			border_mc = new Sprite();
			addChild( border_mc )
		}
		
		private function make_percent_text():void {
			percent_txt = new TextField();
			percent_txt.autoSize = TextFieldAutoSize.LEFT;
			
			/*************************************************************/
			// This block check for an embedded font and sets up the font
			// The font must be in your library and exported with a Class name
			if ( font_id != "" ) {
				var font = new font_id();
				var txt_fmt:TextFormat = new TextFormat();
				txt_fmt.font = font.fontName;
				txt_fmt.size = font_size;
				percent_txt.defaultTextFormat = txt_fmt;
				percent_txt.embedFonts = true;
			}
			/*************************************************************/
			
			percent_txt.selectable = false
			
			set_percent_text_properties()
			addChild( percent_txt );
			percent_txt.visible = false;
		}
		
		private function set_percent_text_properties():void {
			percent_txt.textColor = border_color;
			percent_txt.x = border_weight / 2;
			percent_txt.y = border_weight / 2;
		}
		
		private function on_progress( e:ProgressEvent ):void {
			var p:Number = e.bytesLoaded / e.bytesTotal;
			percent_txt.text = Math.round( p * 100 ) + "%";
		}
		
		private function on_complete( e:Event ):void {
			percent_txt.visible = false;
		}
		
		
		/* Public functions */
		public function load_image( _url:String ):void {
			var req:URLRequest = new URLRequest( _url );
			loader.load( req );
			percent_txt.visible = true;
		}
		public function set_position( _x:Number, _y:Number ):void {
			loader.x = _x;
			loader.y = _y;
		}
		
		public function set_border( _weight:Number, _color:uint ):void {
			border_weight = _weight;
			border_color = _color;
			set_percent_text_properties();
			redraw_image();
		}
	}// End of class
}// End of package














